package uk.co.petertribble.jangle;

import snmp.*;
import java.net.InetAddress;

/**
 * A simple test harness that walks the snmp tree on localhost.
 */
public class SnmpTest {

    /**
     * Walk the snmp tree.
     *
     * @param args command line arguments, ignored
     */
    public static void main(String args[]) {
	try {
	    String community = "public";
	    int version = 0;    // SNMPv1
	    InetAddress hostAddress = InetAddress.getByName("localhost");
	    SNMPv1CommunicationInterface comInterface =
		new SNMPv1CommunicationInterface(version, hostAddress,
						community);
	    String itemID = "";
	    // start here, but why...
	    String retrievedID = "1.3.6.1.2.1";
	    while (!retrievedID.equals(itemID)) {
		itemID = retrievedID;
		SNMPVarBindList newVars = comInterface.getNextMIBEntry(itemID);
		SNMPSequence pair = (SNMPSequence)(newVars.getSNMPObjectAt(0));
		SNMPObjectIdentifier snmpOID =
		    (SNMPObjectIdentifier) pair.getSNMPObjectAt(0);
		SNMPObject snmpValue = pair.getSNMPObjectAt(1);
		retrievedID = snmpOID.toString();
		String typeString = snmpValue.getClass().getName();
		if (typeString.equals("snmp.SNMPOctetString")) {
		    String snmpString = snmpValue.toString();
		    // truncate at first null character
		    int nullLocation = snmpString.indexOf('\0');
		    if (nullLocation >= 0) {
			snmpString = snmpString.substring(0, nullLocation);
		    }
		    System.out.println("OID: " + snmpOID + "  type: "
				+ typeString + "  value: " + snmpString);
		    System.out.println("  (hex: "
			+ ((SNMPOctetString)snmpValue).toHexString() + ")");
		} else {
		    System.out.println("OID: " + snmpOID + "  type: "
				+ typeString + "  value: " + snmpValue);
		}
	    }
	} catch (Exception e) {
	    System.err.println("Oops!");
	}
    }
}
